// ****************************************************************************
// *           KE-Visual - Visualisierungssprache unter Windows           		*
// ****************************************************************************
// * Sprache                : KE-Visual, C++                                  *
// * programmiert von       : Peter Thaus           									*
// * letzte nderung am     : 24.09.1997                                      *
// * Library-Version        : 1.14.002                                        *
// ****************************************************************************
// *                          Datei : SYS_TEXT.H                            	*
// ****************************************************************************
// * Makros fr Zugriffe auf SYS_TEXT.INI                                     *
// ****************************************************************************

#ifndef __SYS_TEXT_H
#define __SYS_TEXT_H
#define __KEB_SYS_TEXT_H


// ****************************************************************************
// * Fehlercodes fr den Compiler                                             *
// ****************************************************************************

#define	CERR_NO_ERROR                        	0
#define	CERR_UNKNOWN_ERROR							-1
#define	CERR_COMMAND_NOT_ALLOWED_FOR_SOURCETEXT  -2
#define	CERR_UNDEFINED_STRING_COMMAND       	-10
#define	CERR_STRING_EXPECTED                	-11
#define	CERR_STRING_CONSTANT_EXCEEDS_LINE   	-12
#define	CERR_VARIABLE_MUST_BE_STRING     		-13
#define	CERR_VARIABLE_MUST_BE_DOUBLE     		-14

#define	CERR_END_OF_LINE_EXPECTED           	-20
#define	CERR_LINE_TOO_LONG							-21

// Fehler in der Syntax
#define	CERR_SYNTAX_ERROR                   	-30
// Komma erwartet, aber nicht angetroffen
#define	CERR_COMMA_EXPECTED                 	-31
// ein bestimmtes Zeichen erwartet, aber nicht angetroffen
#define	CERR_UNEXPECTED_CHAR                	-32

// zu einer offenen Klammer fehlt das Gegenstck
#define	CERR_MISSING_CLOSING_BRACKET				-33
#define	CERR_SEMICOLON_MISSING              	-34

#define	CERR_UNKNOWN_TEXTSTYLE                	-40

#define	CERR_UNKNOWN_MACRO                  	-51
#define	CERR_ILLEGAL_MACRO_DEFINITION				-52
#define	CERR_MACRO_ALREADY_DEFINED_DIFFERENT	-53

#define	CERR_START_OF_BLOCK_MISSING         	-60
#define	CERR_END_OF_BLOCK_MISSING           	-61
#define	CERR_ENDSTRINGTABLE_NOT_FOUND       	-62
#define	CERR_OPEN_COMMENT_AT_END_OF_BLOCK		-63
#define	CERR_ILLEGAL_NUMBER_FOR_STRINGTABLE		-64

#define	CERR_ILLEGAL_VARIABLE_NAME          	-70
#define	CERR_ILLEGAL_VARIABLE_TYPE          	-71
#define	CERR_ILLEGAL_VARIABLE_EXPRESSION    	-72
#define	CERR_UNKNOWN_VARIABLE_TYPE  				-73
#define	CERR_VARIABLES_CANT_BE_DEFINED_HERE		-74
#define	CERR_VARIABLE_ALREADY_DEFINED				-75

#define	CERR_ILLEGAL_VALUE                  	-80
#define	CERR_INVALID_INTEGER_PARAMETER			-81

#define	CERR_CASE_OUTSIDE_SWITCH            	-90
#define	CERR_DEFAULT_OUTSIDE_SWITCH         	-91
#define	CERR_SWITCH_EXPECTS_BLOCK					-92

#define	CERR_BREAK_WITHOUT_BLOCK            	-100
#define	CERR_CONTINUE_WITHOUT_BLOCK         	-101

#define	CERR_TOO_MANY_NESTED_SCOPES         	-110
#define	CERR_SOURCETEXT_NOT_FOUND					-111
#define	CERR_SOURCETEXT_NOT_READABLE				-112

#define	CERR_PROCEDURE_NOT_IN_PROC_BLOCK			-120
#define	CERR_START_OF_PROCEDURE_MISSING			-121
#define	CERR_UNKNOWN_PROCEDURE_CALL   			-122
#define	CERR_NESTED_PROCEDURE						-123
#define	CERR_ILLEGAL_PROCEDURE_NAME				-124
#define	CERR_TOO_MANY_PROCEDURE_PARAMETERS		-125
#define	CERR_OPEN_PROCEDURE							-126
#define	CERR_PROCEDURE_ALREADY_DEFINED	  		-127
#define	CERR_RETURN_OUTSIDE_PROCEDURE				-128
#define	CERR_ILLEGAL_FUNCTION_TYPE					-129

#define	CERR_FOR_EXPECTS_BLOCK						-140
#define	CERR_VARIABLE_ASSIGNMENT_EXPECTED		-141
#define	CERR_COMMAND_NOT_ALLOWED_IN_PROCEDURES	-142
#define	CERR_WHILE_EXPECTS_BLOCK					-143

// Stringtabelle
#define	CERR_STRING_ALREADY_EXISTS 				-150
#define	CERR_ILLEGAL_STRING_NUMBER					-151

// Speicherreservierung
#define	CERR_CODE_EXCEEDS_64K     					-160
#define	CERR_CANNOT_ALLOCATE_MEMORY				-161

// Formelinterprteter
// unerlaubtes Zeichen ASCII (128 - 255) im Ausdruck
#define CERR_ILLEGAL_CHAR     						-200

// Klammer zu ohne Klammer auf
#define CERR_BRACKET_NOT_SUITABLE					-201

// unbekannter Ausdruck
#define CERR_UNKNOWN_EXPRESSION						-202

// illegale Zahlendarstellung, z.B. "512.3.2"
#define CERR_ILLEGAL_NUMBER_FORMAT					-203

// "Ausdrcke vom Typ char drfen nur 1 Zeichen lang sein:\n$6"
#define CERR_CHARACTERLENGTH_MUST_BE_1				-204

// "Ende der Formel nicht gefunden\n$6"
#define CERR_END_OF_EXPRESSION_NOT_FOUND			-205

// conditional defines
#define CERR_UNEXPECTED_EOF_IN_CONDITIONAL		-210
#define CERR_ENDIF_WITHOUT_IFDEF 				  	-211
#define CERR_ELSE_WITHOUT_IFDEF 				  		-212

// Warnungen (positive Werte)
#define	CWRN_WARNING_FILE_NOT_FOUND					   	1
#define	CWRN_VARIABLE_DECLARED_BUT_NEVER_USED				2
#define	CWRN_VARIABLE_ASSIGNED_BUT_NEVER_USED				3
#define	CWRN_POSSIBLE_USE_OF_VAR_BEFORE_DEFINITION		4
#define	CWRN_VARIABLE_NOT_DEFINED_FOR_USE					5
#define	CWRN_VARIABLE_NAME_NOT_CONFORM						6
#define	CWRN_FUNCTION_NAME_NOT_CONFORM						7
#define	CWRN_CONST_STRING_USED_INSTEAD_OF_STRINGTABLE	8
#define	CWRN_MACRO_DEFINED_TWICE								9
#define	CWRN_VARIABLES_NEED_SQUARE_BRACKETS					10

// ****************************************************************************
// * Fehlercodes zur Laufzeit (Runtime) eines Screen-/Druckertextes           *
// ****************************************************************************

#define	RERR_NO_ERROR                        	 0
#define	RERR_UNKNOWN_ERROR							-1

// Verschachtelungstiefe ist zu hoch
#define	RERR_TOO_MANY_NESTED_SCOPES         	-10	// V0.55

#define	RERR_DIAGRAM_PLOT_NOT_DEFINED				-44

#define	RERR_ILLEGAL_CURSOR_STORAGE_NUMBER		-70
#define	RERR_UNKNOWN_COORDINATE_MODE				-71

#define	RERR_ILLEGAL_FLAG_NUMBER					-80
#define	RERR_ILLEGAL_LOCAL_VARIABLE_NUMBER		-81
#define	RERR_ILLEGAL_SYSTEM_VARIABLE_NUMBER		-82
#define	RERR_ILLEGAL_USER_VARIABLE_NUMBER		-83
#define	RERR_ILLEGAL_TEXT_BUFFER_NUMBER			-84
#define	RERR_SETVAR_DIVISOR_IS_ZERO				-85		// V1.01.010
#define	RERR_UNDEFINED_TEXTBUFFER	 				-86
#define	RERR_UNDEFINED_TIMER       				-87		// V0.36

#define	RERR_COMMAND_NOT_ALLOWED_IN_SWITCH  	-90

#define	RERR_QUICKSTRING_ALREADY_EXISTS			-100
#define	RERR_PAGE_NOT_DEFINED 						-101
#define	RERR_ID_OBJECT_ALREADY_EXISTS				-102
#define	RERR_NO_ID_OBJECT_DEFINED 					-103
#define	RERR_ID_OBJECT_NOT_DEFINED 				-104
#define	RERR_TOO_MANY_ID_OBJECTS_DEFINED			-105
#define	RERR_ANIMATION_OBJECT_NOT_DEFINED		-106
#define	RERR_ANIMATION_ALREADY_EXISTS				-107
#define	RERR_MINIMUM_EQUAL_MAXIMUM					-108

// ID-Listen
// "Kein Objekt dieses Typs mit ID #1 definiert!"
#define  RERR_OBJECT_WITH_ID_UNDEFINED				-110
// "Gleiches Objekt mit ID #1 bereits definiert!"
#define  RERR_OBJECT_WITH_ID_DEFINED				-111
// "Maximum (#1) mu grer als Minimum (#2) sein!"
#define  RERR_MAXIMUM_MUST_BE_LARGER_MINIMUM 	-112
// "illegale ID #1; gltige Werte sind 1..32767"
#define	RERR_ILLEGAL_ID								-113	//  V1.03.000

// "Keine lokalen Variablen definiert"
#define	RERR_NO_LOCAL_VARIABLES_DEFINED			-120	// V0.39

// "Keine Benutzervariablen definiert"
#define	RERR_NO_USER_VARIABLES_DEFINED			-121	// V0.39

// "Keine Systemvariablen definiert"
#define	RERR_NO_SYSTEM_VARIABLES_DEFINED			-122	// V0.39

// "Fehler bei Programmausfhrung\nWinExec ($6); Fehlercode = #1"
#define	RERR_WINEXEC_ERROR							-123	// V1.10.010

// Fehler beim Formelinterpreter
// ein Wert wird durch 0 geteilt
#define	RERR_DIVISION_BY_ZERO     					-200

// negativer Wurzelausdruck, Logarithmus von 0 oder negativ...
#define	RERR_ILLEGAL_VALUE		  					-201

// keine Data-Elemente mehr vorhanden
#define	RERR_NO_MORE_DATA								-202

// Fehler im Tokenfeld
#define	RERR_TOKENFIELD_ERROR	  					-203

// Datei (z.B. Bitmap, Video) nicht gefunden
#define	RERR_FILE_NOT_FOUND  	  					-204


// ****************************************************************************
// * gemischte Fehlercodes (Mixed)                                            *
// ****************************************************************************

#define	MERR_NO_ERROR									 0
#define	MERR_UNKNOWN_ERROR							-1

#define	MERR_NO_TIMERS_FREE							-10
// Druckerzugriff nicht mglich V1.01.018
#define	MERR_PRINTER_NOT_ACCESSIBLE				-11
// "Fehler bei Programmausfhrung\nWinExec ($6); Fehlercode = #1"
#define	MERR_WINEXEC_ERROR							-12	// V1.11.009


// RS232
#define	MERR_INTERFACE_CANNOT_BE_INITIALIZED	-20
#define	MERR_DCB_CANNOT_BE_CREATED					-21
#define	MERR_COMMUNICATION_DEVICE_COULD_NOT_BE_SETUP -22
#define	MERR_CRITICAL_TRANSMISSION_ERROR    	-23

// Screen- / Druckertexte
#define	MERR_SCREENTEXT_STARTED_TWICE       	-30
#define	MERR_SCREENTEXT_NOT_FOUND           	-31

// Fehler whrend der Initialisierung
#define	MERR_PATH_NOT_SET								-40
#define	MERR_NETBIOS_NOT_AVAILABLE					-41
#define	MERR_NETBIOS_NODENAME_ALREADY_EXISTS	-42
#define	MERR_NETBIOS_GROUPNAME_CANNOT_BE_SET	-43

// Bereiche in Variable.ini fehlen
#define	MERR_SECTION_SYSVAR_NOT_FOUND       	-50
#define	MERR_SECTION_USERVAR_NOT_FOUND			-51
#define	MERR_SECTION_TEXTBUFFER_NOT_FOUND		-52
#define	MERR_SECTION_VARIABLES_NOT_FOUND			-53

// Dateifehler
// Datei kann nicht geffnet werden
#define	MERR_FILE_NOT_FOUND							-60
// Bitmap ist nicht vom geforderten Typ WMF bzw. BMP
#define	MERR_ILLEGAL_BITMAP_TYPE					-61

#define	MERR_VARIABLE_INI_ILLEGAL_SYSVAR			-70
#define	MERR_VARIABLE_INI_ILLEGAL_USERVAR		-71
#define	MERR_VARIABLE_INI_ILLEGAL_KEY_NUMBER	-72
#define	MERR_VARIABLE_INI_ILLEGAL_TEXTBUFFER	-73
#define	MERR_VARIABLE_INI_LINE_IGNORED      	-74
#define	MERR_MACRO_FILE_NOT_FOUND					-75
#define	MERR_VARIABLE_INI_SYNTAX_ERROR	     	-76		// V0.62
#define	MERR_VARIABLE_INI_SYSVAR_ALREADY_DEFINED  -77	// V0.62
#define	MERR_VARIABLE_INI_USERVAR_ALREADY_DEFINED -78	// V0.62
#define	MERR_VARIABLE_INI_TEXTBUFFER_ALREADY_DEFINED -79	// V1.00.003

// Es knnen nur #1 Y-Achsen pro Diagramm (ID=#2) definiert werden !
#define	MERR_TOO_MANY_Y_AXLES_PER_DIAGRAM		-80
// "Y-Achse #1 existiert bereits fr Diagramm #2!"
#define	MERR_Y_AXLE_ALREADY_EXISTS 				-81

// Lnge des Eingabefeldes ist zu lang: #1
#define	MERR_INPUT_FIELD_TOO_LONG 					-82

// Vorgabe fr Eingabefeld ist lnger als Lnge des Eingabefeldes (#1)!
#define	MERR_INPUT_DEFAULT_FORMAT_TOO_LONG		-83

// "Syntax-Fehler bei Buchstabenmaske
#define	MERR_INPUT_SYNTAX_ERROR           		-84

// Bitmap kann nicht ausgegeben werden
#define	MERR_CANNOT_PRINT_BITMAP 					-85

// Druckervorschau: "Metafile $6 nicht gefunden"
#define	MERR_METAFILE_NOT_FOUND  					-86

// "Laufwerk $6: Verlangter Speicher = #1 MByte, vorhandener Speicher = #2 MByte"
#define	MERR_TOO_FEW_DISK_SPACE  					-90

// Verzeichnis setzen mit SetDirectory: Verzeichnis existiert nicht
#define	MERR_DIRECTORY_DOES_NOT_EXISTS			-91

// zu wenige Flags definiert (weniger als vom System bentigt werden)
#define	MERR_TOO_FEW_FLAGS							-92

// zu wenige Systemvariablen definiert (weniger als vom System bentigt werden)
#define	MERR_TOO_FEW_SYSVARS							-93

// zu wenige Textpuffer definiert (weniger als vom System bentigt werden)
#define	MERR_TOO_FEW_TEXTBUFFERS					-94

// zu viele Flags definiert (>64kByte)
#define	MERR_TOO_MANY_FLAGS							-95

// zu viele Systemvariablen definiert (>64kByte)
#define	MERR_TOO_MANY_SYSVARS						-96

// zu viele Uservariablen definiert (>64kByte)
#define	MERR_TOO_MANY_USERVARS						-97

// zu viele Textpuffer definiert (>64kByte)
#define	MERR_TOO_MANY_TEXTBUFFERS					-98

// Das Argument liegt auerhalb des gltigen Definitionsbereichs fr die
// Funktion. Beispiel: log(-1).
#define	MERR_DOMAIN_ERROR								-100

// Der Rckgabewert wre eine mathematische Singularitt. Beispiel: pow(0, -2)
#define	MERR_SING_ERROR								-101

// Das Argument wrde einen Rckgabewert erzeugen, dessen Wert grer
// als DBL_MAX (bzw. LDBL_MAX) ist. Beispiel: exp(1000).
#define	MERR_OVERFLOW_ERROR							-102


// ****************************************************************************
// * Datenbankfehlercodes                                                    	*
// ****************************************************************************

#define	DERR_NO_ERROR									 0
#define	DERR_UNKNOWN_ERROR							-1
#define	DERR_CANNOT_INIT_DLLBASE					-2
#define	DERR_FILE_NOT_FOUND      					-3

#define	DERR_CANNOT_OPEN_DATABASE					-10
#define	DERR_DATABASE_INI_NOT_FOUND				-11
#define	DERR_TOO_MANY_INDICES_DEFINED				-12
#define	DERR_SYNTAX_ERROR_IN_INDEX_EXPRESSION	-13
#define	DERR_UNKNOWN_FIELD_IN_INDEX_DEFINITION	-14
#define	DERR_SYNTAX_ERROR_IN_DATABASE_DECLARATION	-15
#define	DERR_ILLEGAL_AREA           				-16
#define	DERR_ILLEGAL_AREA_SECTION   				-17
#define	DERR_DATABASE_NOT_FOUND						-18
#define	DERR_ENTRY_NOT_FOUND							-19
#define	DERR_DATABASE_WITHOUT_FIELDS				-20
#define	DERR_SYNTAX_FEHLER							-21
#define	DERR_UNKNOWN_ENTRY_IN_SECTION				-22
#define	DERR_ILLEGAL_INDEX_NUMBER					-23
#define	DERR_ILLEGAL_FIELD_NAME  					-24
#define	DERR_UNKNOWN_AREA								-25
#define	DERR_UNKNOWN_INDEX							-26
#define	DERR_ILLEGAL_ARRAY_SIZE						-27
#define	DERR_CANNOT_OPEN_DATABASE_EXCLUSIVE		-28

// erwartete Bereiche in database.ini nicht gefunden
#define	DERR_SECTION_NOT_FOUND						-30
#define	DERR_DEFINTION_NOT_FOUND					-31

// Auslesen der Database.ini
#define	DERR_UNDEFINED_TEXTBUFFER           	-40
#define	DERR_ILLEGAL_FLAG_NUMBER               -41
#define	DERR_ILLEGAL_SYSTEM_VARIABLE_NUMBER    -42
#define	DERR_ILLEGAL_USER_VARIABLE_NUMBER      -43
#define	DERR_ILLEGAL_TEXT_BUFFER_NUMBER        -44
#define	DERR_VARIABLE_NUMBER_CANNOT_BE_TEXT    -45
#define	DERR_ILLEGAL_PLOT_NUMBER					-46

// Fehlercodes fr Memofelder
#define	DERR_CANNOT_WRITE_MEMO_FIELD				-50
#define	DERR_CANNOT_READ_MEMO_FIELD				-51

// Fehlercodes von DLL-Base (Werte MSSEN so bleiben, da innerhalb DLLBASE.DLL
// definiert (vgl. Handbuch DLLBASE.DLL, S.164/Anhang 8)
#define	BERR_DATABASE_OPEN		   				 (1)
#define	BERR_DATABASE_BAD_FORMAT                (2)
// ... u.v.m.

// ****************************************************************************
// * Systemstatuszeilen                                                       *
// ****************************************************************************

#define	SERR_PRINTER_ERROR							-10
#define	SERR_NO_STATUSLINE							-11

#endif //  __SYS_TEXT_H

// ****************************************************************************
// *                          Ende Datei : SYS_TEXT.H                       	*
// ****************************************************************************

